# Code and data to accompany 'A climatic suitability indicator to support *Leishmania infantum* surveillance in Europe: a modelling study'

### Description

This repository includes the code and data to reproduce the analysis of 'A climatic suitability indicator to support *Leishmania infantum* surveillance in Europe: a modelling study', available [soon]().

To reproduce the models and proposed analysis as described in the paper, please run scripts 01 to 07. Note that due to the stochastic behaviour of the modelling methods, your new results might be slightly different.

The main study results and figures can be reproduced by running script 07 only, without the need of re-running the models.

![](figs/manuscript_fig.png)

**Predicted climatic suitability for Leishmania infantum by NUTS3 regions.** Pink shaded areas represent suitable regions in 2001-2010 and 2011-2020. Dark pink areas represent newly suitable regions in 2011-2020. Yellow shaded areas represent unsuitable regions in both periods. Grey shaded areas are countries not included in the models. Countries with blue borders are currently considered endemic for leishmaniasis.

### Input data

- Occurrence of human and/or animal leishmaniasis caused by *L. infantum* in Europe: [ECDC](https://data.europa.eu/doi/10.2900/823484)
- Occurrence of sand flies in Europe: [ECDC](https://www.ecdc.europa.eu/en/disease-vectors/surveillance-and-disease-data/phlebotomine-maps)
- Human cases of Visceral Leishmaniasis in France, Greece, and Spain: [ECDC](https://data.europa.eu/doi/10.2900/823484)
- Human cases of Visceral Leishmaniasis in Italy: [Moirano et al. 2022](https://doi.org/10.3390/tropicalmed7110337)
- Canine seroprevalence of *L. infantum* in Spain: [Gálvez et al. 2020](https://doi.org/10.1186/s13071-020-04081-7)
- Canine seroprevalence of *L. infantum* in Portugal: [Cortes et al. 2012](https://doi.org/10.1016/j.vetpar.2012.04.028), [Almeida et al. 2022](https://doi.org/10.3390/microorganisms10112262)
- Bioclimatic indicators: calculated from [ERA5-Land](https://doi.org/10.24381/CDS.68D2BB30)
- Land cover: [CORINE](https://land.copernicus.eu/pan-european/corine-land-cover)
- Elevation: [SRTM](https://www.worldclim.org/data/worldclim21.html)
- Population at risk of poverty and social exclusion: [EUROSTAT](https://ec.europa.eu/eurostat/statistics-explained/index.php?title=Living_conditions_in_Europe_-_poverty_and_social_exclusion)
- Population size in France, Greece, Italy, and Spain: [EUROSTAT](https://ec.europa.eu/eurostat/data/database)
- European territorial division (NUTS3): [EUROSTAT](https://ec.europa.eu/eurostat/fr/web/gisco/geodata/statistical-units/territorial-units-statistics)

### Additional information

Harmonised datasets for running the scripts are also available at [Zenodo]().

This study was part of the [Lancet Countdown on Health and Climate Change in Europe](https://www.lancetcountdown.org/europe/) and its main results can be found in the [2024 Report published at The Lancet Public Health](https://doi.org/10.1016/S2468-2667(24)00055-0).

The authors acknowledge funding from the European Union’s Horizon Europe research and innovation programme under the projects [IDAlert](https://idalertproject.eu) and [CLIMOS](https://climos-project.eu), part of the [European Climate-Health Cluster](https://climate-health.eu).

#### Authors

[Bruno M. Carvalho](https://www.bsc.es/moreira-de-carvalho-bruno), Carla Maia, Orin Courtenay, [Alba Llabrés-Brustenga](https://www.bsc.es/llabres-alba), [Martín Lotto Batista](https://www.bsc.es/lotto-batista-martin), [Giovenale Moirano](https://www.bsc.es/moirano-giovenale), [Kim R. van Daalen](https://www.bsc.es/van-daalen-kim-robin), Jan C. Semenza, [Rachel Lowe](https://www.bsc.es/lowe-rachel).

Contact information: [bruno.carvalho@bsc.es](mailto:bruno.carvalho@bsc.es)

Date of creation: 03 June 2024
