# Function to search for the best parameter values by 10-fold cross-validation
# adapted from <https://carpentries-incubator.github.io/r-ml-tabular-data/06-Exploration/index.html>

BestParamSearch <- function(paramDF, dtrain, pa_weights, nthread) {
  paramList <- lapply(split(paramDF, 1:nrow(paramDF)), as.list)
  bestResults <- tibble()
  pb <- txtProgressBar(style = 3)
  for(i in seq(length(paramList))) {
    rwCV <- xgb.cv(params = paramList[[i]],
                   data = dtrain,
                   nthread = nthread,
                   nrounds = 500, 
                   nfold = 10,
                   early_stopping_rounds = 10,
                   verbose = FALSE,
                   eval.metric = "auc",
                   scale_pos_weight = pa_weights)
    bestResults <- bestResults %>% 
      bind_rows(rwCV$evaluation_log[rwCV$best_iteration])
    gc() 
    setTxtProgressBar(pb, i/length(paramList))
  }
  close(pb)
  return(bind_cols(paramDF, bestResults) %>% arrange(test_auc_mean))
}